@@ -1,30 +1,33 @@
-# -*- coding: utf-8 -*-
-
 import datetime
 import logging
 import urllib.parse as urlparse
 import xml.etree.ElementTree as etree
-
 from inspect import getfullargspec
+from inspect import signature
 
 import requests
 from requests.exceptions import HTTPError
 
-from .base import Storage, normalize_meta_value
-from .. import exceptions, http, utils
-from ..http import HTTP_STORAGE_PARAMETERS, USERAGENT, prepare_auth, \
-    prepare_client_cert, prepare_verify
+from .. import exceptions
+from .. import http
+from .. import utils
+from ..http import prepare_auth
+from ..http import prepare_client_cert
+from ..http import prepare_verify
+from ..http import USERAGENT
 from ..vobject import Item
+from .base import normalize_meta_value
+from .base import Storage
 
 
 dav_logger = logging.getLogger(__name__)
 
-CALDAV_DT_FORMAT = '%Y%m%dT%H%M%SZ'
+CALDAV_DT_FORMAT = "%Y%m%dT%H%M%SZ"
 
 
 def _generate_path_reserved_chars():
     for x in "/?#[]!$&'()*+,;":
-        x = urlparse.quote(x, '')
+        x = urlparse.quote(x, "")
         yield x.upper()
         yield x.lower()
 
@@ -36,7 +39,7 @@ del _generate_path_reserved_chars
 def _contains_quoted_reserved_chars(x):
     for y in _path_reserved_chars:
         if y in x:
-            dav_logger.debug('Unsafe character: {!r}'.format(y))
+            dav_logger.debug(f"Unsafe character: {y!r}")
             return True
     return False
 
@@ -47,19 +50,19 @@ def _assert_multistatus_success(r):
         root = _parse_xml(r.content)
     except InvalidXMLResponse:
         return
-    for status in root.findall('.//{DAV:}status'):
+    for status in root.findall(".//{DAV:}status"):
         parts = status.text.strip().split()
         try:
             st = int(parts[1])
         except (ValueError, IndexError):
             continue
         if st < 200 or st >= 400:
-            raise HTTPError('Server error: {}'.format(st))
+            raise HTTPError(f"Server error: {st}")
 
 
 def _normalize_href(base, href):
-    '''Normalize the href to be a path only relative to hostname and
-    schema.'''
+    """Normalize the href to be a path only relative to hostname and
+    schema."""
     orig_href = href
     if not href:
         raise ValueError(href)
@@ -77,13 +80,12 @@ def _normalize_href(base, href):
         old_x = x
         x = urlparse.unquote(x)
 
-    x = urlparse.quote(x, '/@%:')
+    x = urlparse.quote(x, "/@%:")
 
     if orig_href == x:
-        dav_logger.debug('Already normalized: {!r}'.format(x))
+        dav_logger.debug(f"Already normalized: {x!r}")
     else:
-        dav_logger.debug('Normalized URL from {!r} to {!r}'
-                         .format(orig_href, x))
+        dav_logger.debug("Normalized URL from {!r} to {!r}".format(orig_href, x))
 
     return x
 
@@ -93,8 +95,8 @@ class InvalidXMLResponse(exceptions.InvalidResponse):
 
 
 _BAD_XML_CHARS = (
-    b'\x00\x01\x02\x03\x04\x05\x06\x07\x08\x0b\x0c\x0e\x0f'
-    b'\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1a\x1b\x1c\x1d\x1e\x1f'
+    b"\x00\x01\x02\x03\x04\x05\x06\x07\x08\x0b\x0c\x0e\x0f"
+    b"\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1a\x1b\x1c\x1d\x1e\x1f"
 )
 
 
@@ -102,8 +104,8 @@ def _clean_body(content, bad_chars=_BAD_XML_CHARS):
     new_content = content.translate(None, bad_chars)
     if new_content != content:
         dav_logger.warning(
-            'Your server incorrectly returned ASCII control characters in its '
-            'XML. Vdirsyncer ignores those, but this is a bug in your server.'
+            "Your server incorrectly returned ASCII control characters in its "
+            "XML. Vdirsyncer ignores those, but this is a bug in your server."
         )
     return new_content
 
@@ -112,9 +114,10 @@ def _parse_xml(content):
     try:
         return etree.XML(_clean_body(content))
     except etree.ParseError as e:
-        raise InvalidXMLResponse('Invalid XML encountered: {}\n'
-                                 'Double-check the URLs in your config.'
-                                 .format(e))
+        raise InvalidXMLResponse(
+            "Invalid XML encountered: {}\n"
+            "Double-check the URLs in your config.".format(e)
+        )
 
 
 def _merge_xml(items):
@@ -122,7 +125,7 @@ def _merge_xml(items):
         return None
     rv = items[0]
     for item in items[1:]:
-        rv.extend(item.getiterator())
+        rv.extend(item.iter())
     return rv
 
 
@@ -134,156 +137,152 @@ def _fuzzy_matches_mimetype(strict, weak):
     if strict is None or weak is None:
         return True
 
-    mediatype, subtype = strict.split('/')
+    mediatype, subtype = strict.split("/")
     if subtype in weak:
         return True
     return False
 
 
-class Discover(object):
+class Discover:
     _namespace = None
     _resourcetype = None
     _homeset_xml = None
     _homeset_tag = None
     _well_known_uri = None
     _collection_xml = b"""
-    <d:propfind xmlns:d="DAV:">
-        <d:prop>
-            <d:resourcetype />
-        </d:prop>
-    </d:propfind>
+    <propfind xmlns="DAV:">
+        <prop>
+            <resourcetype />
+        </prop>
+    </propfind>
     """
 
     def __init__(self, session, kwargs):
-        if kwargs.pop('collection', None) is not None:
-            raise TypeError('collection argument must not be given.')
+        if kwargs.pop("collection", None) is not None:
+            raise TypeError("collection argument must not be given.")
 
         self.session = session
         self.kwargs = kwargs
 
     @staticmethod
     def _get_collection_from_url(url):
-        _, collection = url.rstrip('/').rsplit('/', 1)
+        _, collection = url.rstrip("/").rsplit("/", 1)
         return urlparse.unquote(collection)
 
     def find_principal(self):
         try:
-            return self._find_principal_impl('')
+            return self._find_principal_impl("")
         except (HTTPError, exceptions.Error):
-            dav_logger.debug('Trying out well-known URI')
+            dav_logger.debug("Trying out well-known URI")
             return self._find_principal_impl(self._well_known_uri)
 
     def _find_principal_impl(self, url):
         headers = self.session.get_default_headers()
-        headers['Depth'] = '0'
+        headers["Depth"] = "0"
         body = b"""
-        <d:propfind xmlns:d="DAV:">
-            <d:prop>
-                <d:current-user-principal />
-            </d:prop>
-        </d:propfind>
+        <propfind xmlns="DAV:">
+            <prop>
+                <current-user-principal />
+            </prop>
+        </propfind>
         """
 
-        response = self.session.request('PROPFIND', url, headers=headers,
-                                        data=body)
+        response = self.session.request("PROPFIND", url, headers=headers, data=body)
 
         root = _parse_xml(response.content)
-        rv = root.find('.//{DAV:}current-user-principal/{DAV:}href')
+        rv = root.find(".//{DAV:}current-user-principal/{DAV:}href")
         if rv is None:
             # This is for servers that don't support current-user-principal
             # E.g. Synology NAS
             # See https://github.com/pimutils/vdirsyncer/issues/498
             dav_logger.debug(
-                'No current-user-principal returned, re-using URL {}'
-                .format(response.url))
+                "No current-user-principal returned, re-using URL {}".format(
+                    response.url
+                )
+            )
             return response.url
-        return urlparse.urljoin(response.url, rv.text).rstrip('/') + '/'
+        return urlparse.urljoin(response.url, rv.text).rstrip("/") + "/"
 
     def find_home(self):
         url = self.find_principal()
         headers = self.session.get_default_headers()
-        headers['Depth'] = '0'
-        response = self.session.request('PROPFIND', url,
-                                        headers=headers,
-                                        data=self._homeset_xml)
+        headers["Depth"] = "0"
+        response = self.session.request(
+            "PROPFIND", url, headers=headers, data=self._homeset_xml
+        )
 
         root = etree.fromstring(response.content)
         # Better don't do string formatting here, because of XML namespaces
-        rv = root.find('.//' + self._homeset_tag + '/{DAV:}href')
+        rv = root.find(".//" + self._homeset_tag + "/{DAV:}href")
         if rv is None:
-            raise InvalidXMLResponse('Couldn\'t find home-set.')
-        return urlparse.urljoin(response.url, rv.text).rstrip('/') + '/'
+            raise InvalidXMLResponse("Couldn't find home-set.")
+        return urlparse.urljoin(response.url, rv.text).rstrip("/") + "/"
 
     def find_collections(self):
         rv = None
         try:
-            rv = list(self._find_collections_impl(''))
+            rv = list(self._find_collections_impl(""))
         except (HTTPError, exceptions.Error):
             pass
 
         if rv:
             return rv
-        dav_logger.debug('Given URL is not a homeset URL')
+        dav_logger.debug("Given URL is not a homeset URL")
         return self._find_collections_impl(self.find_home())
 
     def _check_collection_resource_type(self, response):
         if self._resourcetype is None:
             return True
 
-        props = _merge_xml(response.findall(
-            '{DAV:}propstat/{DAV:}prop'
-        ))
+        props = _merge_xml(response.findall("{DAV:}propstat/{DAV:}prop"))
         if props is None or not len(props):
-            dav_logger.debug('Skipping, missing <prop>: %s', response)
+            dav_logger.debug("Skipping, missing <prop>: %s", response)
             return False
-        if props.find('{DAV:}resourcetype/' + self._resourcetype) \
-           is None:
-            dav_logger.debug('Skipping, not of resource type %s: %s',
-                             self._resourcetype, response)
+        if props.find("{DAV:}resourcetype/" + self._resourcetype) is None:
+            dav_logger.debug(
+                "Skipping, not of resource type %s: %s", self._resourcetype, response
+            )
             return False
         return True
 
     def _find_collections_impl(self, url):
         headers = self.session.get_default_headers()
-        headers['Depth'] = '1'
-        r = self.session.request('PROPFIND', url, headers=headers,
-                                 data=self._collection_xml)
+        headers["Depth"] = "1"
+        r = self.session.request(
+            "PROPFIND", url, headers=headers, data=self._collection_xml
+        )
         root = _parse_xml(r.content)
         done = set()
-        for response in root.findall('{DAV:}response'):
+        for response in root.findall("{DAV:}response"):
             if not self._check_collection_resource_type(response):
                 continue
 
-            href = response.find('{DAV:}href')
+            href = response.find("{DAV:}href")
             if href is None:
-                raise InvalidXMLResponse('Missing href tag for collection '
-                                         'props.')
+                raise InvalidXMLResponse("Missing href tag for collection " "props.")
             href = urlparse.urljoin(r.url, href.text)
             if href not in done:
                 done.add(href)
-                yield {'href': href}
+                yield {"href": href}
 
     def discover(self):
         for c in self.find_collections():
-            url = c['href']
+            url = c["href"]
             collection = self._get_collection_from_url(url)
             storage_args = dict(self.kwargs)
-            storage_args.update({'url': url, 'collection': collection})
+            storage_args.update({"url": url, "collection": collection})
             yield storage_args
 
     def create(self, collection):
         if collection is None:
-            collection = self._get_collection_from_url(self.kwargs['url'])
+            collection = self._get_collection_from_url(self.kwargs["url"])
 
         for c in self.discover():
-            if c['collection'] == collection:
+            if c["collection"] == collection:
                 return c
 
         home = self.find_home()
-        url = urlparse.urljoin(
-            home,
-            urlparse.quote(collection, '/@')
-        )
+        url = urlparse.urljoin(home, urlparse.quote(collection, "/@"))
 
         try:
             url = self._create_collection_impl(url)
@@ -291,29 +290,30 @@ class Discover(object):
             raise NotImplementedError(e)
         else:
             rv = dict(self.kwargs)
-            rv['collection'] = collection
-            rv['url'] = url
+            rv["collection"] = collection
+            rv["url"] = url
             return rv
 
     def _create_collection_impl(self, url):
-        data = '''<?xml version="1.0" encoding="utf-8" ?>
-            <D:mkcol xmlns:D="DAV:">
-                <D:set>
-                    <D:prop>
-                        <D:resourcetype>
-                            <D:collection/>
+        data = """<?xml version="1.0" encoding="utf-8" ?>
+            <mkcol xmlns="DAV:">
+                <set>
+                    <prop>
+                        <resourcetype>
+                            <collection/>
                             {}
-                        </D:resourcetype>
-                    </D:prop>
-                </D:set>
-            </D:mkcol>
-        '''.format(
-            etree.tostring(etree.Element(self._resourcetype),
-                           encoding='unicode')
-        ).encode('utf-8')
+                        </resourcetype>
+                    </prop>
+                </set>
+            </mkcol>
+        """.format(
+            etree.tostring(etree.Element(self._resourcetype), encoding="unicode")
+        ).encode(
+            "utf-8"
+        )
 
         response = self.session.request(
-            'MKCOL',
+            "MKCOL",
             url,
             data=data,
             headers=self.session.get_default_headers(),
@@ -322,57 +322,64 @@ class Discover(object):
 
 
 class CalDiscover(Discover):
-    _namespace = 'urn:ietf:params:xml:ns:caldav'
-    _resourcetype = '{%s}calendar' % _namespace
+    _namespace = "urn:ietf:params:xml:ns:caldav"
+    _resourcetype = "{%s}calendar" % _namespace
     _homeset_xml = b"""
-    <d:propfind xmlns:d="DAV:" xmlns:c="urn:ietf:params:xml:ns:caldav">
-        <d:prop>
+    <propfind xmlns="DAV:" xmlns:c="urn:ietf:params:xml:ns:caldav">
+        <prop>
             <c:calendar-home-set />
-        </d:prop>
-    </d:propfind>
+        </prop>
+    </propfind>
     """
-    _homeset_tag = '{%s}calendar-home-set' % _namespace
-    _well_known_uri = '/.well-known/caldav'
+    _homeset_tag = "{%s}calendar-home-set" % _namespace
+    _well_known_uri = "/.well-known/caldav"
 
 
 class CardDiscover(Discover):
-    _namespace = 'urn:ietf:params:xml:ns:carddav'
-    _resourcetype = '{%s}addressbook' % _namespace
+    _namespace = "urn:ietf:params:xml:ns:carddav"
+    _resourcetype = "{%s}addressbook" % _namespace
     _homeset_xml = b"""
-    <d:propfind xmlns:d="DAV:" xmlns:c="urn:ietf:params:xml:ns:carddav">
-        <d:prop>
+    <propfind xmlns="DAV:" xmlns:c="urn:ietf:params:xml:ns:carddav">
+        <prop>
             <c:addressbook-home-set />
-        </d:prop>
-    </d:propfind>
+        </prop>
+    </propfind>
     """
-    _homeset_tag = '{%s}addressbook-home-set' % _namespace
-    _well_known_uri = '/.well-known/carddav'
+    _homeset_tag = "{%s}addressbook-home-set" % _namespace
+    _well_known_uri = "/.well-known/carddav"
 
 
-class DAVSession(object):
-    '''
+class DAVSession:
+    """
     A helper class to connect to DAV servers.
-    '''
+    """
 
     @classmethod
     def init_and_remaining_args(cls, **kwargs):
         argspec = getfullargspec(cls.__init__)
-        self_args, remainder = \
-            utils.split_dict(kwargs, argspec.args.__contains__)
+        self_args, remainder = utils.split_dict(kwargs, argspec.args.__contains__)
 
         return cls(**self_args), remainder
 
-    def __init__(self, url, username='', password='', verify=True, auth=None,
-                 useragent=USERAGENT, verify_fingerprint=None,
-                 auth_cert=None):
+    def __init__(
+        self,
+        url,
+        username="",
+        password="",
+        verify=True,
+        auth=None,
+        useragent=USERAGENT,
+        verify_fingerprint=None,
+        auth_cert=None,
+    ):
         self._settings = {
-            'cert': prepare_client_cert(auth_cert),
-            'auth': prepare_auth(auth, username, password)
+            "cert": prepare_client_cert(auth_cert),
+            "auth": prepare_auth(auth, username, password),
         }
         self._settings.update(prepare_verify(verify, verify_fingerprint))
 
         self.useragent = useragent
-        self.url = url.rstrip('/') + '/'
+        self.url = url.rstrip("/") + "/"
 
         self._session = requests.session()
 
@@ -391,23 +398,12 @@ class DAVSession(object):
 
     def get_default_headers(self):
         return {
-            'User-Agent': self.useragent,
-            'Content-Type': 'application/xml; charset=UTF-8'
+            "User-Agent": self.useragent,
+            "Content-Type": "application/xml; charset=UTF-8",
         }
 
 
 class DAVStorage(Storage):
-
-    __doc__ = '''
-    :param url: Base URL or an URL to a collection.
-    ''' + HTTP_STORAGE_PARAMETERS + '''
-
-    .. note::
-
-        Please also see :ref:`supported-servers`, as some servers may not work
-        well.
-    '''
-
     # the file extension of items. Useful for testing against radicale.
     fileext = None
     # mimetype of items
@@ -421,23 +417,21 @@ class DAVStorage(Storage):
     # The DAVSession class to use
     session_class = DAVSession
 
-    _repr_attributes = ('username', 'url')
+    _repr_attributes = ("username", "url")
 
     _property_table = {
-        'displayname': ('displayname', 'DAV:'),
+        "displayname": ("displayname", "DAV:"),
     }
 
     def __init__(self, **kwargs):
         # defined for _repr_attributes
-        self.username = kwargs.get('username')
-        self.url = kwargs.get('url')
+        self.username = kwargs.get("username")
+        self.url = kwargs.get("url")
 
-        self.session, kwargs = \
-            self.session_class.init_and_remaining_args(**kwargs)
-        super(DAVStorage, self).__init__(**kwargs)
+        self.session, kwargs = self.session_class.init_and_remaining_args(**kwargs)
+        super().__init__(**kwargs)
 
-    import inspect
-    __init__.__signature__ = inspect.signature(session_class.__init__)
+    __init__.__signature__ = signature(session_class.__init__)
 
     @classmethod
     def discover(cls, **kwargs):
@@ -472,17 +466,13 @@ class DAVStorage(Storage):
         for href in hrefs:
             if href != self._normalize_href(href):
                 raise exceptions.NotFoundError(href)
-            href_xml.append('<D:href>{}</D:href>'.format(href))
+            href_xml.append(f"<href>{href}</href>")
         if not href_xml:
             return ()
 
-        data = self.get_multi_template \
-            .format(hrefs='\n'.join(href_xml)).encode('utf-8')
+        data = self.get_multi_template.format(hrefs="\n".join(href_xml)).encode("utf-8")
         response = self.session.request(
-            'REPORT',
-            '',
-            data=data,
-            headers=self.session.get_default_headers()
+            "REPORT", "", data=data, headers=self.session.get_default_headers()
         )
         root = _parse_xml(response.content)  # etree only can handle bytes
         rv = []
@@ -490,11 +480,12 @@ class DAVStorage(Storage):
         for href, etag, prop in self._parse_prop_responses(root):
             raw = prop.find(self.get_multi_data_query)
             if raw is None:
-                dav_logger.warning('Skipping {}, the item content is missing.'
-                                   .format(href))
+                dav_logger.warning(
+                    "Skipping {}, the item content is missing.".format(href)
+                )
                 continue
 
-            raw = raw.text or u''
+            raw = raw.text or ""
 
             if isinstance(raw, bytes):
                 raw = raw.decode(response.encoding)
@@ -505,11 +496,9 @@ class DAVStorage(Storage):
                 hrefs_left.remove(href)
             except KeyError:
                 if href in hrefs:
-                    dav_logger.warning('Server sent item twice: {}'
-                                       .format(href))
+                    dav_logger.warning("Server sent item twice: {}".format(href))
                 else:
-                    dav_logger.warning('Server sent unsolicited item: {}'
-                                       .format(href))
+                    dav_logger.warning("Server sent unsolicited item: {}".format(href))
             else:
                 rv.append((href, Item(raw), etag))
         for href in hrefs_left:
@@ -518,17 +507,14 @@ class DAVStorage(Storage):
 
     def _put(self, href, item, etag):
         headers = self.session.get_default_headers()
-        headers['Content-Type'] = self.item_mimetype
+        headers["Content-Type"] = self.item_mimetype
         if etag is None:
-            headers['If-None-Match'] = '*'
+            headers["If-None-Match"] = "*"
         else:
-            headers['If-Match'] = etag
+            headers["If-Match"] = etag
 
         response = self.session.request(
-            'PUT',
-            href,
-            data=item.raw.encode('utf-8'),
-            headers=headers
+            "PUT", href, data=item.raw.encode("utf-8"), headers=headers
         )
 
         _assert_multistatus_success(response)
@@ -547,13 +533,13 @@ class DAVStorage(Storage):
         #
         # In such cases we return a constant etag. The next synchronization
         # will then detect an etag change and will download the new item.
-        etag = response.headers.get('etag', None)
+        etag = response.headers.get("etag", None)
         href = self._normalize_href(response.url)
         return href, etag
 
     def update(self, href, item, etag):
         if etag is None:
-            raise ValueError('etag must be given and must not be None.')
+            raise ValueError("etag must be given and must not be None.")
         href, etag = self._put(self._normalize_href(href), item, etag)
         return etag
 
@@ -564,23 +550,17 @@ class DAVStorage(Storage):
     def delete(self, href, etag):
         href = self._normalize_href(href)
         headers = self.session.get_default_headers()
-        headers.update({
-            'If-Match': etag
-        })
+        headers.update({"If-Match": etag})
 
-        self.session.request(
-            'DELETE',
-            href,
-            headers=headers
-        )
+        self.session.request("DELETE", href, headers=headers)
 
     def _parse_prop_responses(self, root, handled_hrefs=None):
         if handled_hrefs is None:
             handled_hrefs = set()
-        for response in root.iter('{DAV:}response'):
-            href = response.find('{DAV:}href')
+        for response in root.iter("{DAV:}response"):
+            href = response.find("{DAV:}href")
             if href is None:
-                dav_logger.error('Skipping response, href is missing.')
+                dav_logger.error("Skipping response, href is missing.")
                 continue
 
             href = self._normalize_href(href.text)
@@ -591,34 +571,34 @@ class DAVStorage(Storage):
                 #   https://github.com/pimutils/vdirsyncer/issues/88
                 # - Davmail
                 #   https://github.com/pimutils/vdirsyncer/issues/144
-                dav_logger.warning('Skipping identical href: {!r}'
-                                   .format(href))
+                dav_logger.warning("Skipping identical href: {!r}".format(href))
                 continue
 
-            props = response.findall('{DAV:}propstat/{DAV:}prop')
+            props = response.findall("{DAV:}propstat/{DAV:}prop")
             if props is None or not len(props):
-                dav_logger.debug('Skipping {!r}, properties are missing.'
-                                 .format(href))
+                dav_logger.debug("Skipping {!r}, properties are missing.".format(href))
                 continue
             else:
                 props = _merge_xml(props)
 
-            if props.find('{DAV:}resourcetype/{DAV:}collection') is not None:
-                dav_logger.debug('Skipping {!r}, is collection.'.format(href))
+            if props.find("{DAV:}resourcetype/{DAV:}collection") is not None:
+                dav_logger.debug(f"Skipping {href!r}, is collection.")
                 continue
 
-            etag = getattr(props.find('{DAV:}getetag'), 'text', '')
+            etag = getattr(props.find("{DAV:}getetag"), "text", "")
             if not etag:
-                dav_logger.debug('Skipping {!r}, etag property is missing.'
-                                 .format(href))
+                dav_logger.debug(
+                    "Skipping {!r}, etag property is missing.".format(href)
+                )
                 continue
 
-            contenttype = getattr(props.find('{DAV:}getcontenttype'),
-                                  'text', None)
+            contenttype = getattr(props.find("{DAV:}getcontenttype"), "text", None)
             if not self._is_item_mimetype(contenttype):
-                dav_logger.debug('Skipping {!r}, {!r} != {!r}.'
-                                 .format(href, contenttype,
-                                         self.item_mimetype))
+                dav_logger.debug(
+                    "Skipping {!r}, {!r} != {!r}.".format(
+                        href, contenttype, self.item_mimetype
+                    )
+                )
                 continue
 
             handled_hrefs.add(href)
@@ -626,22 +606,21 @@ class DAVStorage(Storage):
 
     def list(self):
         headers = self.session.get_default_headers()
-        headers['Depth'] = '1'
+        headers["Depth"] = "1"
 
-        data = '''<?xml version="1.0" encoding="utf-8" ?>
-            <D:propfind xmlns:D="DAV:">
-                <D:prop>
-                    <D:resourcetype/>
-                    <D:getcontenttype/>
-                    <D:getetag/>
-                </D:prop>
-            </D:propfind>
-            '''.encode('utf-8')
+        data = b"""<?xml version="1.0" encoding="utf-8" ?>
+            <propfind xmlns="DAV:">
+                <prop>
+                    <resourcetype/>
+                    <getcontenttype/>
+                    <getetag/>
+                </prop>
+            </propfind>
+            """
 
         # We use a PROPFIND request instead of addressbook-query due to issues
         # with Zimbra. See https://github.com/pimutils/vdirsyncer/issues/83
-        response = self.session.request('PROPFIND', '', data=data,
-                                        headers=headers)
+        response = self.session.request("PROPFIND", "", data=data, headers=headers)
         root = _parse_xml(response.content)
 
         rv = self._parse_prop_responses(root)
@@ -654,32 +633,31 @@ class DAVStorage(Storage):
         except KeyError:
             raise exceptions.UnsupportedMetadataError()
 
-        xpath = '{%s}%s' % (namespace, tagname)
-        data = '''<?xml version="1.0" encoding="utf-8" ?>
-            <D:propfind xmlns:D="DAV:">
-                <D:prop>
+        xpath = f"{{{namespace}}}{tagname}"
+        data = """<?xml version="1.0" encoding="utf-8" ?>
+            <propfind xmlns="DAV:">
+                <prop>
                     {}
-                </D:prop>
-            </D:propfind>
-        '''.format(
-            etree.tostring(etree.Element(xpath), encoding='unicode')
-        ).encode('utf-8')
+                </prop>
+            </propfind>
+        """.format(
+            etree.tostring(etree.Element(xpath), encoding="unicode")
+        ).encode(
+            "utf-8"
+        )
 
         headers = self.session.get_default_headers()
-        headers['Depth'] = '0'
+        headers["Depth"] = "0"
 
-        response = self.session.request(
-            'PROPFIND', '',
-            data=data, headers=headers
-        )
+        response = self.session.request("PROPFIND", "", data=data, headers=headers)
 
         root = _parse_xml(response.content)
 
-        for prop in root.findall('.//' + xpath):
-            text = normalize_meta_value(getattr(prop, 'text', None))
+        for prop in root.findall(".//" + xpath):
+            text = normalize_meta_value(getattr(prop, "text", None))
             if text:
                 return text
-        return u''
+        return ""
 
     def set_meta(self, key, value):
         try:
@@ -687,23 +665,26 @@ class DAVStorage(Storage):
         except KeyError:
             raise exceptions.UnsupportedMetadataError()
 
-        lxml_selector = '{%s}%s' % (namespace, tagname)
+        lxml_selector = f"{{{namespace}}}{tagname}"
         element = etree.Element(lxml_selector)
         element.text = normalize_meta_value(value)
 
-        data = '''<?xml version="1.0" encoding="utf-8" ?>
-            <D:propertyupdate xmlns:D="DAV:">
-                <D:set>
-                    <D:prop>
+        data = """<?xml version="1.0" encoding="utf-8" ?>
+            <propertyupdate xmlns="DAV:">
+                <set>
+                    <prop>
                         {}
-                    </D:prop>
-                </D:set>
-            </D:propertyupdate>
-        '''.format(etree.tostring(element, encoding='unicode')).encode('utf-8')
+                    </prop>
+                </set>
+            </propertyupdate>
+        """.format(
+            etree.tostring(element, encoding="unicode")
+        ).encode(
+            "utf-8"
+        )
 
         self.session.request(
-            'PROPPATCH', '',
-            data=data, headers=self.session.get_default_headers()
+            "PROPPATCH", "", data=data, headers=self.session.get_default_headers()
         )
 
         # XXX: Response content is currently ignored. Though exceptions are
@@ -714,117 +695,89 @@ class DAVStorage(Storage):
 
 
 class CalDAVStorage(DAVStorage):
-
-    __doc__ = '''
-    CalDAV.
-
-    You can set a timerange to synchronize with the parameters ``start_date``
-    and ``end_date``. Inside those parameters, you can use any Python
-    expression to return a valid :py:class:`datetime.datetime` object. For
-    example, the following would synchronize the timerange from one year in the
-    past to one year in the future::
-
-        start_date = datetime.now() - timedelta(days=365)
-        end_date = datetime.now() + timedelta(days=365)
-
-    Either both or none have to be specified. The default is to synchronize
-    everything.
-
-    You can set ``item_types`` to restrict the *kind of items* you want to
-    synchronize. For example, if you want to only synchronize events (but don't
-    download any tasks from the server), set ``item_types = ["VEVENT"]``. If
-    you want to synchronize events and tasks, but have some ``VJOURNAL`` items
-    on the server you don't want to synchronize, use ``item_types = ["VEVENT",
-    "VTODO"]``.
-
-    :param start_date: Start date of timerange to show, default -inf.
-    :param end_date: End date of timerange to show, default +inf.
-    :param item_types: Kind of items to show. The default, the empty list, is
-        to show all. This depends on particular features on the server, the
-        results are not validated.
-    ''' + DAVStorage.__doc__
-
-    storage_name = 'caldav'
-    fileext = '.ics'
-    item_mimetype = 'text/calendar'
+    storage_name = "caldav"
+    fileext = ".ics"
+    item_mimetype = "text/calendar"
     discovery_class = CalDiscover
 
     start_date = None
     end_date = None
 
-    get_multi_template = '''<?xml version="1.0" encoding="utf-8" ?>
-        <C:calendar-multiget xmlns:D="DAV:"
+    get_multi_template = """<?xml version="1.0" encoding="utf-8" ?>
+        <C:calendar-multiget xmlns="DAV:"
             xmlns:C="urn:ietf:params:xml:ns:caldav">
-            <D:prop>
-                <D:getetag/>
+            <prop>
+                <getetag/>
                 <C:calendar-data/>
-            </D:prop>
+            </prop>
             {hrefs}
-        </C:calendar-multiget>'''
+        </C:calendar-multiget>"""
 
-    get_multi_data_query = '{urn:ietf:params:xml:ns:caldav}calendar-data'
+    get_multi_data_query = "{urn:ietf:params:xml:ns:caldav}calendar-data"
 
     _property_table = dict(DAVStorage._property_table)
-    _property_table.update({
-        'color': ('calendar-color', 'http://apple.com/ns/ical/'),
-    })
+    _property_table.update(
+        {
+            "color": ("calendar-color", "http://apple.com/ns/ical/"),
+        }
+    )
 
-    def __init__(self, start_date=None, end_date=None,
-                 item_types=(), **kwargs):
-        super(CalDAVStorage, self).__init__(**kwargs)
+    def __init__(self, start_date=None, end_date=None, item_types=(), **kwargs):
+        super().__init__(**kwargs)
         if not isinstance(item_types, (list, tuple)):
-            raise exceptions.UserError('item_types must be a list.')
+            raise exceptions.UserError("item_types must be a list.")
 
         self.item_types = tuple(item_types)
         if (start_date is None) != (end_date is None):
-            raise exceptions.UserError('If start_date is given, '
-                                       'end_date has to be given too.')
+            raise exceptions.UserError(
+                "If start_date is given, " "end_date has to be given too."
+            )
         elif start_date is not None and end_date is not None:
             namespace = dict(datetime.__dict__)
-            namespace['start_date'] = self.start_date = \
-                (eval(start_date, namespace)
-                 if isinstance(start_date, (bytes, str))
-                 else start_date)
-            self.end_date = \
-                (eval(end_date, namespace)
-                 if isinstance(end_date, (bytes, str))
-                 else end_date)
+            namespace["start_date"] = self.start_date = (
+                eval(start_date, namespace)
+                if isinstance(start_date, (bytes, str))
+                else start_date
+            )
+            self.end_date = (
+                eval(end_date, namespace)
+                if isinstance(end_date, (bytes, str))
+                else end_date
+            )
 
     @staticmethod
     def _get_list_filters(components, start, end):
         if components:
-            caldavfilter = '''
+            caldavfilter = """
                 <C:comp-filter name="VCALENDAR">
                     <C:comp-filter name="{component}">
                         {timefilter}
                     </C:comp-filter>
                 </C:comp-filter>
-                '''
+                """
 
             if start is not None and end is not None:
                 start = start.strftime(CALDAV_DT_FORMAT)
                 end = end.strftime(CALDAV_DT_FORMAT)
 
-                timefilter = ('<C:time-range start="{start}" end="{end}"/>'
-                              .format(start=start, end=end))
+                timefilter = '<C:time-range start="{start}" end="{end}"/>'.format(
+                    start=start, end=end
+                )
             else:
-                timefilter = ''
+                timefilter = ""
 
             for component in components:
-                yield caldavfilter.format(component=component,
-                                          timefilter=timefilter)
+                yield caldavfilter.format(component=component, timefilter=timefilter)
         else:
             if start is not None and end is not None:
-                for x in CalDAVStorage._get_list_filters(('VTODO', 'VEVENT'),
-                                                         start, end):
-                    yield x
+                yield from CalDAVStorage._get_list_filters(
+                    ("VTODO", "VEVENT"), start, end
+                )
 
     def list(self):
-        caldavfilters = list(self._get_list_filters(
-            self.item_types,
-            self.start_date,
-            self.end_date
-        ))
+        caldavfilters = list(
+            self._get_list_filters(self.item_types, self.start_date, self.end_date)
+        )
         if not caldavfilters:
             # If we don't have any filters (which is the default), taking the
             # risk of sending a calendar-query is not necessary. There doesn't
@@ -833,34 +786,32 @@ class CalDAVStorage(DAVStorage):
             # instead?
             #
             # See https://github.com/dmfs/tasks/issues/118 for backstory.
-            for x in DAVStorage.list(self):
-                yield x
+            yield from DAVStorage.list(self)
 
-        data = '''<?xml version="1.0" encoding="utf-8" ?>
-            <C:calendar-query xmlns:D="DAV:"
+        data = """<?xml version="1.0" encoding="utf-8" ?>
+            <C:calendar-query xmlns="DAV:"
                 xmlns:C="urn:ietf:params:xml:ns:caldav">
-                <D:prop>
-                    <D:getcontenttype/>
-                    <D:getetag/>
-                </D:prop>
+                <prop>
+                    <getcontenttype/>
+                    <getetag/>
+                </prop>
                 <C:filter>
                 {caldavfilter}
                 </C:filter>
-            </C:calendar-query>'''
+            </C:calendar-query>"""
 
         headers = self.session.get_default_headers()
         # https://github.com/pimutils/vdirsyncer/issues/166
         # The default in CalDAV's calendar-queries is 0, but the examples use
         # an explicit value of 1 for querying items. it is extremely unclear in
         # the spec which values from WebDAV are actually allowed.
-        headers['Depth'] = '1'
+        headers["Depth"] = "1"
 
         handled_hrefs = set()
 
         for caldavfilter in caldavfilters:
-            xml = data.format(caldavfilter=caldavfilter).encode('utf-8')
-            response = self.session.request('REPORT', '', data=xml,
-                                            headers=headers)
+            xml = data.format(caldavfilter=caldavfilter).encode("utf-8")
+            response = self.session.request("REPORT", "", data=xml, headers=headers)
             root = _parse_xml(response.content)
             rv = self._parse_prop_responses(root, handled_hrefs)
             for href, etag, _prop in rv:
@@ -868,24 +819,19 @@ class CalDAVStorage(DAVStorage):
 
 
 class CardDAVStorage(DAVStorage):
-
-    __doc__ = '''
-    CardDAV.
-    ''' + DAVStorage.__doc__
-
-    storage_name = 'carddav'
-    fileext = '.vcf'
-    item_mimetype = 'text/vcard'
+    storage_name = "carddav"
+    fileext = ".vcf"
+    item_mimetype = "text/vcard"
     discovery_class = CardDiscover
 
-    get_multi_template = '''<?xml version="1.0" encoding="utf-8" ?>
-            <C:addressbook-multiget xmlns:D="DAV:"
+    get_multi_template = """<?xml version="1.0" encoding="utf-8" ?>
+            <C:addressbook-multiget xmlns="DAV:"
                     xmlns:C="urn:ietf:params:xml:ns:carddav">
-                <D:prop>
-                    <D:getetag/>
+                <prop>
+                    <getetag/>
                     <C:address-data/>
-                </D:prop>
+                </prop>
                 {hrefs}
-            </C:addressbook-multiget>'''
+            </C:addressbook-multiget>"""
 
-    get_multi_data_query = '{urn:ietf:params:xml:ns:carddav}address-data'
+    get_multi_data_query = "{urn:ietf:params:xml:ns:carddav}address-data"
